@@ -3,15 +3,14 @@
 import numpy as np
 from matplotlib import pyplot as plt
 from warnings import warn
-from typing import Callable, Iterator, Union, Optional, List
 from .cnst import Cnst
 from .s2t import S2T
 from .pct import PCT
 from .sc_tp_t import Hm, HP, Gsn
 from .sc2t import PS2, TSS2
 from .rt2 import RT2
-from .mnt_t import MntPntAmp
-from .mnt_t import MntMltPntAmp
+from tdyno.mnt.mnt_t_fa import MntMltPntAmp
+from tdyno.mnt.mnt_t_poyn import Mnt2DSqPoynU
 
 
 class TDyno:
@@ -437,7 +436,7 @@ class TDyno:
         """
         self.md = mode
 
-    def add_point_monitors(self, delay=0., coords=None, weights=None, omega_min=0., omega_max=2., n_omega=100, norm_factor=1., power=True, flux=False, refer_spectrum=None):
+    def add_point_monitors(self, coords, delay=0., weights=None, omega_min=0., omega_max=2., n_omega=100, norm_factor=1., flux=False, refer_spectrum=None):
         """
         Add monitors to monitor the amplitude of the field on multi points. Record the amplitudes on each, do weighted sum, and do Fourier Transform.
         The monitors only record Ez and Hz for the two corresponding polarizations, respectively.
@@ -455,10 +454,8 @@ class TDyno:
                                     number of frequency points
         norm_factor             :   float
                                     normalization factor for spectrum
-        power                   :   bool
-                                    if true, plot the power spectral density.
         flux                    :   bool
-                                    if true, plot the flux. Overrides `power`.
+                                    if true, plot the flux spectral density. Otherwise plot the power spectral density
         refer_spectrum          :   ndarray[float]
                                     reference spectrum. If supplied, the shown spectrum will be divided by this. This is for convenience, for example, if want to see transmission spectrum.
 
@@ -466,7 +463,47 @@ class TDyno:
         -------
 
         """
-        mnt = MntMltPntAmp(self.st, dt=self.dt, td=delay, coords=coords, wts=weights, omin=omega_min, omax=omega_max, n_o=n_omega, nmf=norm_factor, psd=power, flx=flux, ref_spctrm=refer_spectrum)
+        if flux is True:
+            show = 'flux spectral density'
+        else:
+            show = 'energy spectral density'
+        mnt = MntMltPntAmp(self.st, coords, dt=self.dt, td=delay, wts=weights, omin=omega_min, omax=omega_max, n_o=n_omega, nmf=norm_factor, show=show, ref_spctrm=refer_spectrum)
+        self.mnts.append(mnt)
+
+    def add_poynting_monitor(self,
+                             xmin=None, xmax=None, ymin=None, ymax=None,
+                             delay=None,
+                             omega_min=None, omega_max=None, n_omega=None,
+                             norm_factor=None, refer_spectrum=None,
+                             sides='all'):
+        """
+        Add Poynting flux monitor as a square box. Tracks the total energy flux from inside the box to outside in real time and calculates the spectrum.
+
+        Parameters
+        ----------
+        xmin : float
+        xmax : float
+        ymin : float
+        ymax : float
+        delay : float
+        omega_min : float
+        omega_max : float
+        n_omega : int
+        norm_factor : float
+        refer_spectrum : np.ndarray
+        sides : str
+            Can be "all", or any combinations (any order) of 'l', 'r', 't', 'b'.
+
+        Returns
+        -------
+
+        """
+        mnt = Mnt2DSqPoynU(st=self.st,
+                           xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax,
+                           dt=self.dt, td=delay,
+                           omin=omega_min, omax=omega_max, n_o=n_omega,
+                           nmf=norm_factor, ref_spctrm=refer_spectrum,
+                           whr=sides, plrz=self.polarization)
         self.mnts.append(mnt)
 
     def run(self, skipping=5, vmin=-1., vmax=1., **kwargs):
